@@ -1,13 +1,13 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2019 by Dominique Dumont.
+# This software is Copyright (c) 2005-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::HashId 2.138;
+package Config::Model::HashId 2.140;
 
 use Mouse;
 use 5.10.1;
@@ -136,6 +136,29 @@ sub get_type {
     return 'hash';
 }
 
+sub get_info {
+    my $self = shift;
+
+    my @items = (
+        'type: ' . $self->get_type . ( $self->ordered ? '(ordered)' : '' ),
+        'index: ' . $self->index_type,
+        'cargo: ' . $self->cargo_type,
+    );
+
+    if ( $self->cargo_type eq 'node' ) {
+        push @items, "cargo class: " . $self->config_class_name;
+    }
+
+    foreach my $what (qw/min_index max_index max_nb warn_if_key_match warn_unless_key_match/) {
+        my $v   = $self->$what();
+        my $str = $what;
+        $str =~ s/_/ /g;
+        push @items, "$str: $v" if defined $v;
+    }
+
+    return @items;
+}
+
 # important: return the actual size (not taking into account auto-created stuff)
 sub fetch_size {
     my $self = shift;
@@ -565,7 +588,7 @@ Config::Model::HashId - Handle hash element for configuration model
 
 =head1 VERSION
 
-version 2.138
+version 2.140
 
 =head1 SYNOPSIS
 
@@ -682,6 +705,11 @@ important:
 
 load_data can also be called with a single ref parameter.
 
+=head2 get_info
+
+Returns a list of information related to the hash. See
+L<Config::Model::Value/get_info> for more details.
+
 =head1 AUTHOR
 
 Dominique Dumont, (ddumont at cpan dot org)
@@ -700,7 +728,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2019 by Dominique Dumont.
+This software is Copyright (c) 2005-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
