@@ -1,13 +1,13 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2019 by Dominique Dumont.
+# This software is Copyright (c) 2005-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Role::Grab 2.138;
+package Config::Model::Role::Grab 2.140;
 
 # ABSTRACT: Role to grab data from elsewhere in the tree
 
@@ -163,7 +163,7 @@ COMMAND:
             $logger->debug("grab: cmd '$cmd' -> name '$name', action '$action', arg '$arg'");
         }
 
-        unless ( $obj->has_element($name) ) {
+        unless ( $obj->has_element(name => $name, autoadd => $autoadd) ) {
             if ( $mode eq 'step_by_step' ) {
                 return wantarray ? ( undef, @command ) : undef;
             }
@@ -211,6 +211,7 @@ COMMAND:
         my $next_obj = $obj->fetch_element(
             name          => $name,
             check         => $check,
+            autoadd       => $autoadd,
             accept_hidden => $grab_non_available
         );
 
@@ -369,7 +370,7 @@ Config::Model::Role::Grab - Role to grab data from elsewhere in the tree
 
 =head1 VERSION
 
-version 2.138
+version 2.140
 
 =head1 SYNOPSIS
 
@@ -503,7 +504,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2019 by Dominique Dumont.
+This software is Copyright (c) 2005-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
