@@ -1,22 +1,21 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
+use strict;
+use warnings;
 
 # test inifile backend with multiple ini files
 
-# specify the name of the class to test
-$model_to_test = "MultiMiniIni";
-
 # create minimal model to test ini file backend.
 
 # this class is used by MultiMiniIni class below
-$model->create_config_class(
+my @config_classes = ({
     name    => 'MultiIniTest::Class',
     element => [
         int_with_max => {qw/type leaf value_type integer max 10/},
@@ -27,9 +26,9 @@ $model->create_config_class(
         file        => '&index.conf',
         auto_create => 1,
     },
-);
+});
 
-$model->create_config_class(
+push @config_classes, {
     name => 'MultiMiniIni',
     element => [
         service => {
@@ -49,11 +48,11 @@ $model->create_config_class(
         file        => 'service.pl',
         auto_create => 1,
     },
-);
+};
 
 
 # the test suite
-@tests = (
+my @tests = (
     {
         name  => 'max-overflow',
         load_check => 'no',
@@ -69,4 +68,9 @@ $model->create_config_class(
     },
 );
 
-1;
+return {
+    # specify the name of the class to test
+    model_to_test => "MultiMiniIni",
+    config_classes => \@config_classes,
+    tests => \@tests
+};
